@@ -159,7 +159,8 @@ findMockFile <- function (file) {
 }
 
 requestBody <- function (req) {
-    b <- req$options$postfields
+    ## requestBody returns a string if the request has a body, NULL otherwise
+    b <- req[["options"]][["postfields"]]
     if (length(b) > 0) {
         ## Check length this way because b may be NULL or length 0 raw vector
         b <- rawToChar(b)
